@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20231228';
+our $VERSION = '0.20240131';
 
-# Table last modified: 2023-12-28
+# Table last modified: 2024-01-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -135,12 +135,12 @@ our %ZIP_TABLE = (
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
-    '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
+    '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
     '144' => '(?:8(?:5(?:44|66|5[015]|8[018]|7[057]|2[25]|3[1-356]|1[01356]|0[56])|6(?:02|11|5[056]|7[78]|2[1-36]|6[016])))',
     '145' => '(?:85(?:[23]3|58|66|0[16]|1[15]))',
     '146' => '(?:8(?:5(?:22|31|67|0[135]|5[158]|8[058]|1[0-25]|7[67]|4[034])|6(?:[03]1|10|77|2[03]|5[056]|6[68])))',
-    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|4[03]|7[37]|3[0368]|0[17]|8[45]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|84|4[03]|7[37]|3[0368]|0[17]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:[34]\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|1[02568]|3[01679])|6(?:01|40|1[06]|8[78]|6[025689]|2[026]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
@@ -149,10 +149,10 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|6[168]|5[1-38]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157]|0[179])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|[24][17]|6[168]|5[1-38]|0[1469])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|0[1479]|4[37]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
-    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
+    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
     '164' => '(?:8(?:5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
@@ -160,7 +160,7 @@ our %ZIP_TABLE = (
     '168' => '(?:8(?:5(?:[6-8]0|48|1[0-26]|5[058]|2[05]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
     '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:39|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|7[0467]|2[013467]|0[124-69]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
-    '171' => '(?:8(?:5(?:5[23578]|3[19]|7[027]|4[045]|2[0-35-7]|1[0-2468]|6[0189]|0[1-3578]|8[0268])|422))',
+    '171' => '(?:8(?:5(?:5[23578]|2[0-7]|3[19]|7[027]|4[045]|1[0-2468]|6[0189]|0[1-3578]|8[0268])|422))',
     '173' => '(?:8(?:5(?:[06]1|[23]0|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:[13]0|0[135]|6[027]|5[058]|2[014-6]|8[08])|6(?:12|46|51|3[0369]|8[068]|0[12])|7(?:[01]1|87|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:71|88))',
@@ -182,7 +182,7 @@ our %ZIP_TABLE = (
     '191' => '(?:8(?:5(?:20|0[1-3679]|1[0-2])|6(?:60|86)))',
     '192' => '(?:(?:8(?:5(?:77|85|2[025]|5[01368]|3[235-7]|[16][02568]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-36]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
-    '194' => '(?:(?:8(?:5(?:20|[15][015]|4[03]|7[07]|6[067]|0[1-3578]|8[05689]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
+    '194' => '(?:(?:8(?:5(?:20|[15][015]|4[03]|7[07]|6[067]|0[1-3578]|8[05689]|3[038])|6(?:66|1[0-2]))|029[24-8]))',
     '195' => '(?:85(?:85|5[05]))',
     '196' => '(?:8(?:5(?:[67]0|01|22|33|[58][058]|1[01])|6(?:[01]1|86|6[68])))',
     '197' => '(?:8(?:5(?:[01]1|55)|6(?:01|23)))',
@@ -239,7 +239,7 @@ our %ZIP_TABLE = (
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
     '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|0[1-35-9]|3[4-68]|6[0-467]|2[13478]|1[0-3568])|7(?:1[02357]|0[137]|3[34]|2[02])))',
+    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|1[0-35-8]|0[1-35-9]|3[4-68]|6[0-467]|2[13478])|7(?:1[02357]|0[137]|3[34]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|6[0168]|3[0359]|7[57]|5[0248]|0[1-478]|8[125-8]|4[145]|2[0-28])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|66|77|8[58]|5[05]|0[56])|733))',
@@ -566,7 +566,7 @@ our %ZIP_TABLE = (
     '597' => '(?:8(?:5(?:22|55|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
-    '600' => '(?:8(?:5(?:44|3[03]|6[5-7]|1[19]|5[058]|8[1568]|0[1-356]|7[07]|2[0256])|6(?:01|52|65|8[68])|7(?:11|87|92)))',
+    '600' => '(?:8(?:5(?:44|3[03]|6[5-7]|1[19]|5[058]|0[1-356]|7[07]|8[168]|2[0256])|6(?:01|52|65|8[68])|7(?:11|87|92)))',
     '601' => '(?:(?:8(?:5(?:[26]0|42|88|3[03]|5[09]|0[126]|1[01])|601)|1(?:192|397|495)|0(?:292|797)))',
     '602' => '(?:8(?:5(?:[27]0|01|55|66|8[058]|1[01])|6(?:02|11)|959))',
     '603' => '(?:85(?:11|22|55|77|88))',
@@ -616,7 +616,7 @@ our %ZIP_TABLE = (
     '650' => '(?:8(?:5(?:1[015]|6[05-7]|5[01589]|2[0-258]|0[1-356]|3[0369]|7[015-7]|8[04-689]|4[36])|6(?:[68][06]|7[07])|7(?:87|94)))',
     '651' => '(?:(?:8(?:5(?:[58]5|67|70|1[124]|0[12]|2[56])|798)|2(?:1(?:9[467]|8[0178])|49[24]|295)|01(?:7[0-278]|9[35]|8[578])|1(?:195|596)))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
-    '653' => '(?:85(?:70|85))',
+    '653' => '(?:8(?:5(?:70|85)|76[267]))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
     '655' => '(?:8570)',
     '656' => '(?:(?:1(?:59[28]|395|792)|2(?:[2-4]92|193)|8(?:6[568]6|555)|0(?:492|595)))',
@@ -638,7 +638,7 @@ our %ZIP_TABLE = (
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:[01]1|22|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
     '674' => '(?:8(?:5(?:01|85)|686))',
-    '675' => '(?:(?:8(?:5(?:22|33|66|77|88|1[019]|5[58]|0[15])|6(?:11|8[68]))|01(?:9[2-468]|8[0-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
+    '675' => '(?:(?:8(?:5(?:22|33|66|77|88|1[019]|5[58]|0[15])|6(?:11|8[68]))|01(?:8[0-68]|9[2-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
     '677' => '(?:851[01])',
     '678' => '(?:(?:1(?:29[257]|19[58])|0(?:19[235]|292)|85(?:43|85)))',
@@ -829,7 +829,7 @@ our %ZIP_TABLE = (
     '868' => '(?:(?:8(?:5(?:55|1[15]|0[1-358])|601)|0(?:59[23578]|39[23]|795)))',
     '869' => '(?:(?:0(?:19[238]|29[235]|49[2-4]|59[238]|696)|2(?:59[2358]|69[2356]|49[23])|1(?:29[2358]|19[23])|5(?:39[23]|498|692)|3(?:296|692)|4292))',
     '870' => '(?:(?:8(?:5(?:70|0[1-46]|4[14]|1[013]|5[0158]|[38][58]|2[13-5]|6[02-4])|6(?:46|58|8[6-8]|1[169]|3[4-6]|7[67]|2[07]|6[05]|0[125]))|0(?:1(?:89|9[2-8])|39[235-8]|[29]92|401)|1(?:19[258]|292)))',
-    '871' => '(?:(?:8(?:5(?:21|77|85|5[05]|0[12]|1[01])|6(?:[02]9|42|66|8[68]))|0(?:99[23]|[27]95|192)))',
+    '871' => '(?:(?:8(?:5(?:[58]5|21|77|0[12]|1[01])|6(?:[02]9|42|66|8[68]))|0(?:99[23]|[27]95|192)))',
     '872' => '(?:0592)',
     '873' => '(?:(?:0(?:29[238]|498)|8501))',
     '874' => '(?:8(?:5(?:[01]1|[67]7|38|8[58]|5[578])|6(?:11|39|6[06]|8[68])))',
@@ -848,7 +848,7 @@ our %ZIP_TABLE = (
     '887' => '(?:8(?:585|686))',
     '888' => '(?:8555)',
     '889' => '(?:(?:1(?:49[2358]|69[2356]|99[4-7]|[18]92|795)|0(?:69[235-8]|59[25]|[13]92)|(?:4[2-5]|2[14])92))',
-    '890' => '(?:8(?:5(?:6[05-7]|3[0-35]|1[0-2578]|0[1-9]|8[015689]|4[013-5]|2[0-57]|5[0258]|7[014578])|6(?:[68]6|10|0[13])|7(?:60|9[48])))',
+    '890' => '(?:8(?:5(?:6[05-7]|3[0-35]|1[0-257]|0[1-9]|8[015689]|4[013-5]|2[0-57]|5[0258]|7[014578])|6(?:[68]6|10|0[13])|7(?:60|9[48])))',
     '891' => '(?:(?:0(?:1(?:8[02-46-9]|9[2-8])|49[378]|[67]92)|3(?:19[2-68]|69[23]|79[23])|1(?:39[2-5]|[15]92)|9(?:29[2-6]|192)|(?:[46]2|7[16])92|2(?:39[36]|192)|8293))',
     '892' => '(?:8(?:5(?:20|4[03]|1[25]|8[568]|5[058]|6[367]|3[01359]|0[125])|6(?:11|26|33|50|77|88|0[13])))',
     '893' => '(?:(?:1(?:19[28]|69[23]|298)|8(?:5(?:10|0[12])|611)|(?:02|2[34])92))',
